"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getControllerMethods = void 0;
const path_1 = __importDefault(require("path"));
const metadata_1 = require("./metadata");
function getControllerMethods(controller) {
    const controllerMetadata = metadata_1.getControllerMetadata(controller.constructor);
    if (!controllerMetadata) {
        return [];
    }
    // Get all keys that exist on the controller.
    const keys = [];
    let scanTarget = controller;
    do {
        keys.push(...Object.getOwnPropertyNames(scanTarget));
    } while ((scanTarget = Object.getPrototypeOf(scanTarget)));
    const results = [];
    // Scan the keys for controller methods, and make routes for them.
    for (const key of keys) {
        const method = controller[key];
        if (typeof method !== "function") {
            continue;
        }
        const methodMetadata = metadata_1.getControllerMethodMetadata(method);
        if (!methodMetadata) {
            continue;
        }
        results.push({
            method,
            metadata: methodMetadata,
            path: path_1.default.posix.join(controllerMetadata.path || "/", methodMetadata.path || "/")
        });
    }
    return results;
}
exports.getControllerMethods = getControllerMethods;
//# sourceMappingURL=controller-utils.js.map