"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
const controller_method_args_1 = require("./controller-method-args");
const metadata_1 = require("../metadata");
describe("Controller Method Argument Decorators", function () {
    describe("@body", function () {
        const required = true;
        const schema = { type: "object" };
        class TestClass {
            testMethod(dummyArg, body) { }
        }
        __decorate([
            __param(1, controller_method_args_1.body({ required, schema }))
        ], TestClass.prototype, "testMethod", null);
        it("sets the argument to the body type", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.handlerArgs[1].type).toEqual("body");
        });
        it("sets the request required status", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.request.required).toEqual(required);
        });
        it("sets the request schema", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.request.schema).toEqual(schema);
        });
    });
    describe("@pathParam", function () {
        const paramName = "testParam";
        const schema = { type: "object" };
        class TestClass {
            testMethod(dummyArg, body) { }
        }
        __decorate([
            __param(1, controller_method_args_1.pathParam(paramName, { schema }))
        ], TestClass.prototype, "testMethod", null);
        it("sets the argument to the pathParam type", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            const argMetadata = metadata.handlerArgs[1];
            expect(argMetadata.type).toEqual("pathParam");
        });
        it("sets the paramName", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            const argMetadata = metadata.handlerArgs[1];
            expect(argMetadata.paramName).toEqual(paramName);
        });
        it("sets the path param schema", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.pathParams[paramName].schema).toEqual(schema);
        });
    });
    describe("@queryParam", function () {
        const paramName = "testParam";
        const required = true;
        const schema = { type: "object" };
        class TestClass {
            testMethod(dummyArg, body) { }
        }
        __decorate([
            __param(1, controller_method_args_1.queryParam(paramName, { required, schema }))
        ], TestClass.prototype, "testMethod", null);
        it("sets the argument to the queryParam type", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            const argMetadata = metadata.handlerArgs[1];
            expect(argMetadata.type).toEqual("queryParam");
        });
        it("sets the paramName", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            const argMetadata = metadata.handlerArgs[1];
            expect(argMetadata.paramName).toEqual(paramName);
        });
        it("sets the path param schema", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.queryParams[paramName].schema).toEqual(schema);
        });
        it("sets the path param required status", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.queryParams[paramName].required).toEqual(required);
        });
    });
    describe("@expressRequest", function () {
        class TestClass {
            testMethod(dummyArg, request) { }
        }
        __decorate([
            __param(1, controller_method_args_1.expressRequest())
        ], TestClass.prototype, "testMethod", null);
        it("sets the argument to the request type", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.handlerArgs[1].type).toEqual("request");
        });
    });
    describe("@expressResponse", function () {
        class TestClass {
            testMethod(dummyArg, response) { }
        }
        __decorate([
            __param(1, controller_method_args_1.expressResponse())
        ], TestClass.prototype, "testMethod", null);
        it("sets the argument to the response type", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.handlerArgs[1].type).toEqual("response");
        });
    });
});
//# sourceMappingURL=controller-method-args.spec.js.map