"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.result = exports.ResultBuilder = void 0;
class ResultBuilder {
    constructor(body, contentType, opts) {
        var _a;
        this.handled = false;
        this.raw = false;
        this.statusCode = 200;
        this.headers = {};
        this.cookies = {};
        this.contentType = contentType;
        this.body = body;
        this.raw = (_a = opts.raw) !== null && _a !== void 0 ? _a : false;
        this.handled = this.body === undefined;
    }
    /**
     * Sets the status message of the result.
     * @param status The status code to return.
     */
    status(status) {
        this.statusCode = status;
        return this;
    }
    /**
     * Sets a result header.
     * @param name The name of the header to set.
     * @param value The value of the header to set.
     */
    header(name, value) {
        this.headers[name] = value;
        return this;
    }
    /**
     * Sets a cookie on the result.
     * @param name The name of the cookie.
     * @param value The value of the cookie.
     * @param settings Additional cookie settings.
     */
    cookie(name, value, settings) {
        this.cookies[name] = Object.assign({ value }, (settings || {}));
        return this;
    }
}
exports.ResultBuilder = ResultBuilder;
const resultPartial = function result(...args) {
    if (args.length === 3) {
        return new ResultBuilder(args[3], args[1], args[2]);
    }
    if (args.length === 2) {
        return new ResultBuilder(args[1], args[0], {});
    }
    else if (args.length === 1) {
        return new ResultBuilder(args[0], "application/json", {});
    }
    throw new Error("Unexpected argument count.");
};
resultPartial.handled = () => {
    return new ResultBuilder(undefined, undefined, {});
};
resultPartial.json = (...args) => {
    if (args.length === 2) {
        return new ResultBuilder(args[1], "application/json", args[0]);
    }
    else if (args.length === 1) {
        return new ResultBuilder(args[0], "application/json", {});
    }
    throw new Error("Unexpected argument count.");
};
resultPartial.text = (body) => {
    return new ResultBuilder(body, "text/plain", {});
};
resultPartial.html = (body) => {
    return new ResultBuilder(body, "text/html", {});
};
/**
 * Utility function to assist in building controller results.
 * @param body The body data to return as the result.
 */
exports.result = resultPartial;
//# sourceMappingURL=method-result.js.map